# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from icalendar.parser_tools import data_encode
from icalendar.parser_tools import to_unicode
import unittest


class TestParserTools(unittest.TestCase):

    def test_parser_tools_to_unicode(self):

        self.assertEqual(to_unicode(b'spam'), 'spam')
        self.assertEqual(to_unicode('spam'), 'spam')
        self.assertEqual(to_unicode('spam'.encode('utf-8')), 'spam')
        self.assertEqual(to_unicode(b'\xc6\xb5'), '\u01b5')
        self.assertEqual(to_unicode('\xc6\xb5'.encode('iso-8859-1')),
                         '\u01b5')
        self.assertEqual(to_unicode(b'\xc6\xb5', encoding='ascii'), '\u01b5')
        self.assertEqual(to_unicode(1), 1)
        self.assertEqual(to_unicode(None), None)

    def test_parser_tools_data_encode(self):

        data1 = {
            'k1': 'v1', 'k2': 'v2', 'k3': 'v3',
            'li1': ['it1', 'it2', {'k4': 'v4', 'k5': 'v5'}, 123]
        }
        res = {b'k3': b'v3', b'k2': b'v2', b'k1': b'v1',
               b'li1': [b'it1', b'it2', {b'k5': b'v5', b'k4': b'v4'}, 123]}
        self.assertEqual(data_encode(data1), res)



# -*- coding: utf-8 -*-
import unittest

import datetime
import icalendar
import os


class TestTime(unittest.TestCase):

    def setUp(self):
        icalendar.cal.types_factory.types_map['X-SOMETIME'] = 'time'

    def tearDown(self):
        icalendar.cal.types_factory.types_map.pop('X-SOMETIME')

    def test_create_from_ical(self):
        directory = os.path.dirname(__file__)
        ics = open(os.path.join(directory, 'time.ics'), 'rb')
        cal = icalendar.Calendar.from_ical(ics.read())
        ics.close()

        self.assertEqual(cal['X-SOMETIME'].dt, datetime.time(17, 20, 10))
        self.assertEqual(cal['X-SOMETIME'].to_ical(), '172010')

    def test_create_to_ical(self):
        cal = icalendar.Calendar()
        cal.add('X-SOMETIME', datetime.time(17, 20, 10))
        self.assertTrue(b'X-SOMETIME;VALUE=TIME:172010' in
                        cal.to_ical().splitlines())



# -*- coding: utf-8 -*-
from icalendar import Calendar
from icalendar.prop import vText
import unittest

import os


class TestMultiple(unittest.TestCase):
    """A example with multiple VCALENDAR components"""

    def test_multiple(self):

        directory = os.path.dirname(__file__)
        with open(os.path.join(directory, 'multiple.ics'), 'rb') as fp:
            data = fp.read()
        cals = Calendar.from_ical(data, multiple=True)

        self.assertEqual(len(cals), 2)
        self.assertSequenceEqual([comp.name for comp in cals[0].walk()],
                                 ['VCALENDAR', 'VEVENT'])
        self.assertSequenceEqual([comp.name for comp in cals[1].walk()],
                                 ['VCALENDAR', 'VEVENT', 'VEVENT'])

        self.assertEqual(
            cals[0]['prodid'],
            vText('-//Mozilla.org/NONSGML Mozilla Calendar V1.0//EN')
        )
